@@ -297,6 +297,7 @@ struct _MenuItem menuitems[] = {
 	{N_("_Play / Pause"), "gnome-cd/a-play-menu.png", G_CALLBACK (play_cb)},
 	{N_("_Next track"), "gnome-cd/a-last-menu.png", G_CALLBACK (next_cb)},
 	{N_("_Eject disc"), "gnome-cd/a-eject-menu.png", G_CALLBACK (eject_cb)},
+	{N_("_Help"), GTK_STOCK_HELP, G_CALLBACK (help_cb)},
 	{N_("_About Gnome-CD"), GNOME_STOCK_ABOUT, G_CALLBACK (about_cb)},
 	{NULL, NULL, NULL}
 };
@@ -399,7 +400,6 @@ init_player (void)
 	if (gcd->cdrom == NULL) {
 		if (error != NULL) {
 			gcd_warning ("%s", error);
-			g_error_free (error);
 		}
 	} else {
 		g_signal_connect (G_OBJECT (gcd->cdrom), "status-changed",
@@ -480,13 +480,12 @@ init_player (void)
 	gtk_box_pack_start (GTK_BOX (top_hbox), display_box, TRUE, TRUE, 0);
 
 	/* Volume slider */
-	gcd->slider = gtk_vscale_new_with_range (0.0, 255.0, 1.0);
-	gtk_range_set_inverted (GTK_RANGE (gcd->slider), TRUE);
+	gcd->slider = gtk_vscale_new_with_range (-255.0, 0.0, 1.0);
 	gtk_scale_set_draw_value (GTK_SCALE (gcd->slider), FALSE);
 	gtk_box_pack_start (GTK_BOX (top_hbox), gcd->slider, FALSE, FALSE, 0);
 	
 	gtk_tooltips_set_tip (gcd->tooltips, GTK_WIDGET (gcd->slider),
-			      _("Volume Control"), NULL);
+			      _("Volume control"), NULL);
 
 	gtk_box_pack_start (GTK_BOX (gcd->vbox), top_hbox, TRUE, TRUE, 0);
 
@@ -630,8 +629,8 @@ main (int argc, char *argv[])
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
 
-	gnome_program_init ("Gnome-CD", VERSION, LIBGNOMEUI_MODULE, 
-			    argc, argv, NULL);
+	gnome_program_init ("gnome-cd", VERSION, LIBGNOMEUI_MODULE, 
+			    argc, argv, GNOME_PARAM_APP_DATADIR, DATADIR, NULL);
 	client = gnome_master_client ();
     	g_signal_connect (client, "save_yourself",
                          G_CALLBACK (save_session), (gpointer) argv[0]);
